@@ -1,9 +1,10 @@
 import logging
-from .config import VCR
 from logging import NullHandler
-from .record_mode import RecordMode as mode  # noqa import is not used in this file
 
-__version__ = "4.2.1"
+from .config import VCR
+from .record_mode import RecordMode as mode  # noqa: F401
+
+__version__ = "6.0.2"
 
 logging.getLogger(__name__).addHandler(NullHandler())
 
